#! /usr/bin/env bash
# SPDX-License-Identifier: MIT

$XGETTEXT *.cpp -o $podir/kio5_info.pot
